class ArcLayer extends Layer
	
	constructor: (@options={}) ->
		@options.backgroundColor ?= null
		@options.lineColor ?= 'rgba(255,255,255,1.0)'
		@options.lineWidth ?= 1
		@options.gradientColorTop ?= 'rgba(255,255,255,1.0)'
		@options.gradientColorBottom ?= 'rgba(255,255,255,0.0)'
		@options.wedgePercent ?= 0.18
		super @options
		
		@html = """
			<svg viewBox='-#{@strokeWidth/2} -#{@strokeWidth/2} #{@viewBox} #{@viewBox}' id='svg#{@id}'>
				<circle fill='none' stroke='#{@color}' stroke-linecap='round'
					stroke-width      = '#{@strokeWidth}'
					stroke-dasharray  = '#{@.pathLength}'
					stroke-dashoffset = '0'
					cx = '#{@radius}'
					cy = '#{@radius}'
					r  = '#{@radius}'>
			</svg>"""
		
		obj = @
		Utils.domComplete ->
			query = '#svg' + obj.id + ' circle'
			obj.path = document.querySelector(query)
			obj.path.style.transition = "stroke 0.3s ease-out"
			obj.updateOffset(obj.wedgePercent)
	
	@define 'wedgePercent',
		get: -> 
			@options.wedgePercent
		set: (value) -> 
			@options.wedgePercent = value		

	@define 'radius',
		get: -> 
			@options.radius
		set: (value) -> 
			@options.radius = value
			@updateSize()
			
	@define 'strokeWidth',
		get: -> 
			@options.strokeWidth
		set: (value) -> 
			@options.strokeWidth = value
			@updateSize()
	
	@define 'viewBox',
		get: -> 
			@options.viewBox
		set: (value) -> 
			@options.viewBox = value
	
	@define 'color',
		get: -> 
			@options.color
		set: (value) -> 
			@options.color = value
			if @path
				@path.style.stroke = @color
				#@path.setAttribute 'stroke', @color
	
	@define 'percent',
		get: -> 
			@options.percent
		set: (value) -> 
			@options.percent = value
			o = Utils.modulate(@percent, [0, 1], [1, @.wedgePercent])			
			@path.setAttribute 'stroke-dashoffset', @pathLength*o

	updateSize: ->
		@viewBox = (@radius*2) + @strokeWidth
		@width = @viewBox
		@height = @viewBox
		@pathLength = 2 * Math.PI * @radius
	
	updateOffset: (offset) ->
		@path.setAttribute 'stroke-dashoffset', @pathLength*offset
		@.rotation = 90 + ((360*offset)/2)

			
module.exports = ArcLayer